@@ -8,6 +8,8 @@ __all__ = [
     "add_parameters_to_doc",
     "add_kwargs_of",
     "compute_property",
+    "static_property",
+    "call_method",
 ]
 
 from types import MethodType
@@ -189,3 +191,28 @@ class compute_property(property):
         except AttributeError:
             setattr(obj, self.key, super().__get__(obj, owner))
             return self.__get__(obj, owner)
+
+
+class static_property:
+    "Decorator similar to staticmethod but returns a property"
+
+    def __init__(self, fnc):
+        self.fget = fnc
+        self.__doc__ = fnc.__doc__
+        self.__name__ = fnc.__name__
+
+    def __get__(self, obj, owner=None):
+        if obj is None:
+            return self.fget()
+        return self.fget()
+
+
+def call_method(self, method, *args, **kwargs):
+    "Calls a method of the class. Method can be either a string, function or a method itself"
+    if isinstance(method, str):
+        return getattr(self, method)(*args, **kwargs)
+    if hasattr(method, "__self__") and method.__self__ is self:
+        return method(*args, **kwargs)
+    if callable(method):
+        return method(self, *args, **kwargs)
+    raise TypeError(f"Unexpected type {type(method)}")
